@@ -29,13 +29,11 @@ function(xy, CEPlevel=0.5, dstTarget=100, conversion="m2cm", accuracy=FALSE,
     }
 
     ## check if we can do robust estimation if so required
-    if(nrow(xy) < 4) {
-        haveRob <- FALSE
-        if(doRob) {
-            warning("We need >= 4 points for robust estimations")
-        }
+    haveRob <- if(nrow(xy) < 4) {
+        if(doRob) { warning("We need >= 4 points for robust estimations") }
+        FALSE
     } else {
-        haveRob <- TRUE
+        TRUE
     }                                    # if(nrow(xy) < 4)
 
     #####-----------------------------------------------------------------------
